use std::fs;
use std::io;

enum Orientation {
    N,
    E,
    S,
    W,
}

enum Instruction {
    L,
    R,
    F,
}

fn parse_orientation(c: char) -> Result<Orientation, &'static str> {
    match c {
        'N' => Ok(Orientation::N),
        'E' => Ok(Orientation::E),
        'S' => Ok(Orientation::S),
        'W' => Ok(Orientation::W),
        _ => Err("Invalid character, does not match any orientations"),
    }
}

fn parse_instruction(c: char) -> Result<Instruction, &'static str> {
    match c {
        'L' => Ok(Instruction::L),
        'R' => Ok(Instruction::R),
        'F' => Ok(Instruction::F),
        _ => Err("Invalid character, does not match any instructions"),
    }
}

fn open_file(filename: &str) -> io::Result<String> {
    let content = fs::read_to_string(filename)?;
    Ok(content)
}

fn main() {
    let conf = open_file("two_robots.txt");
}

#[cfg(test)]
mod tests {
    use super::*;

    #[test]
    fn test_parse_orientation() {
        assert!(parse_orientation('N').is_ok());
        assert!(parse_orientation('E').is_ok());
        assert!(parse_orientation('S').is_ok());
        assert!(parse_orientation('W').is_ok());
        assert!(parse_orientation('Z').is_err());
    }

    #[test]
    fn test_parse_instruction() {
        assert!(parse_instruction('L').is_ok());
        assert!(parse_instruction('R').is_ok());
        assert!(parse_instruction('F').is_ok());
        assert!(parse_instruction('Z').is_err());
    }

    #[test]
    fn test_open_file() {
        assert!(open_file("two_robots.txt").is_ok());
        assert!(open_file("test_unexisting_file.extension").is_err());
    }

}
